@@ -49,8 +49,10 @@ class Manager:
     schema = os.path.join(os.path.dirname(__file__),
                           "schema",
                           "workflow.yml")
+    wkf_cfg = os.path.join(self.get_parameter("main", "$.laboro.workflowdir"),
+                           filename)
     self._workflow_config = Validator().validate_from_files(schema=schema,
-                                                            instance=filename)
+                                                            instance=wkf_cfg)
 
   def __init__(self, main_config):
     self.main_config = main_config
