@@ -1,4 +1,9 @@
+import logging
 from types import SimpleNamespace
+from laboro.logger import LaboroLogger
+
+logging.setLoggerClass(LaboroLogger)
+logger = logging.getLogger("laboro.main")
 
 
 class Store:
@@ -47,3 +52,6 @@ class Store:
     self.step_item = None
     self.action_item = None
     self.method_item = None
+
+  def as_dict(self):
+    return {key: value for key, value in self.storage.__dict__.items()}
