@@ -28,17 +28,16 @@ class Parser:
         res = Interpreter(usersyms=store).eval(expression,
                                                raise_errors=True,
                                                show_errors=False)
-        if isinstance(res, str):
-          return Parser().literal_eval(res)
-        return Parser().parse(res, store)
-      except (TypeError, ValueError, SyntaxError, NameError):
+      except (KeyError, TypeError, ValueError, SyntaxError, NameError):
         return expression
-    else:
-      return expression
+      if isinstance(res, str):
+        return Parser().literal_eval(res)
+      return Parser().parse(res, store)
+    return expression
 
   @staticmethod
   def literal_eval(expression):
     try:
       return literal_eval(expression)
-    except (ValueError, SyntaxError):
+    except (KeyError, TypeError, ValueError, SyntaxError, NameError):
       return expression
